@@ -20,6 +20,7 @@ config = {
         'max_size': int(os.environ.get('POSTGRES_MAXSIZE', 15)),
         'statement_cache_size': int(os.environ.get('STATEMENT_CACHE_SIZE', 0))
     },
+    'AIOCACHE_DISABLE': os.environ.get('AIOCACHE_DISABLE', False),
     'app_dir': os.environ.get('APP_DIR', 'app'),
     'domain': os.environ.get('DOMAIN', 'example.com'),
     'AUTH_URL': os.environ.get('AUTH_URL', ''),
@@ -27,6 +28,7 @@ config = {
     'middlewares': [
         'aiohttp_boilerplate.middleware.defaults.cross_origin_rules',
         'aiohttp_boilerplate.middleware.defaults.url_status_200',
+        'aiohttp_boilerplate.middleware.defaults.erase_header_server',
     ]
 }
 
